@@ -2,7 +2,7 @@ parse_text <- function(content, type = NULL, encoding = NULL) {
   charset <- if (!is.null(type)) parse_media(type)$params$charset
   encoding <- toupper(encoding %||% charset %||% "ISO-8859-1")
 
-  if (!(encoding %in% iconvlist())) {
+  if (!(tolower(encoding) %in% tolower(iconvlist()))) {
     message("Unknown encoding ", encoding, ". ",
       "Defaulting to latin1 (ISO-8859-1).")
     encoding <- "ISO-8859-1"
@@ -17,22 +17,18 @@ parse_auto <- function(content, type = NULL, encoding = NULL, ...) {
   }
 
   if (is.null(type)) {
-    stop("Unknown mime type: can't parse automatically. Use the type ",
+    stop("Unknown mime type: can't parse automatically. Use the `type` ",
       "argument to specify manually.", call. = FALSE)
   }
 
   mt <- parse_media(type)
-  if (mt$type == "text") {
-    content <- parse_text(content, type, encoding = encoding)
-  }
-
   parser <- parsers[[mt$complete]]
   if (is.null(parser)) {
     stop("No automatic parser available for ", mt$complete, ".",
       call. = FALSE)
-  } else {
-    parser(content, ...)
   }
+
+  parser(content, type = type, encoding = encoding, ...)
 }
 
 parseability <- function(type) {
@@ -53,45 +49,53 @@ parsers <- new.env(parent = emptyenv())
 # Binary formats ---------------------------------------------------------------
 
 # http://www.ietf.org/rfc/rfc4627.txt - section 3. (encoding)
-parsers$`application/json` <- function(x, simplifyVector = FALSE, ...) {
+parsers$`application/json` <- function(x, type = NULL, encoding = NULL,
+                                       simplifyVector = FALSE, ...) {
   jsonlite::fromJSON(parse_text(x, encoding = "UTF-8"),
     simplifyVector = simplifyVector, ...)
 }
-parsers$`application/x-www-form-urlencoded` <- function(x) {
+parsers$`application/x-www-form-urlencoded` <- function(x, type = NULL,
+                                                        encoding = NULL, ...) {
   parse_query(parse_text(x, encoding = "UTF-8"))
 }
-parsers$`application/xml` <- function(x, ...) {
+parsers$`application/xml` <- function(x, type = NULL, encoding = NULL, ...) {
   need_package("XML")
   XML::xmlParse(parse_text(x, encoding = "UTF-8"), ...)
 }
 
 # Text formats -----------------------------------------------------------------
-parsers$`image/jpeg` <- function(x) {
+parsers$`image/jpeg` <- function(x, type = NULL, encoding = NULL, ...) {
   need_package("jpeg")
   jpeg::readJPEG(x)
 }
 
-parsers$`image/png` <- function(x) {
+parsers$`image/png` <- function(x, type = NULL, encoding = NULL, ...) {
   need_package("png")
   png::readPNG(x)
 }
 
-parsers$`text/plain` <- function(x) x
+parsers$`text/plain` <- function(x, type = NULL, encoding = NULL, ...) {
+  parse_text(x, type = type, encoding = encoding)
+}
 
-parsers$`text/html` <- function(x, ...) {
+parsers$`text/html` <- function(x, type = NULL, encoding = NULL, ...) {
   need_package("XML")
-  XML::htmlParse(x, ...)
+  text <- parse_text(x, type = type, encoding = encoding)
+  XML::htmlParse(text, ...)
 }
 
-parsers$`text/xml` <- function(x, ...) {
+parsers$`text/xml` <- function(x, type = NULL, encoding = NULL, ...) {
   need_package("XML")
-  XML::xmlParse(x, ...)
+  text <- parse_text(x, type = type, encoding = encoding)
+  XML::xmlParse(text, ...)
 }
 
-parsers$`text/csv` <- function(x, ...) {
-  read.csv(text = x, stringsAsFactors = FALSE, ...)
+parsers$`text/csv` <- function(x, type = NULL, encoding = NULL, ...) {
+  text <- parse_text(x, type = type, encoding = encoding)
+  read.csv(text = text, stringsAsFactors = FALSE, ...)
 }
 
-parsers$`text/tab-separated-values` <- function(x, ...) {
-  read.delim(text = x, stringsAsFactors = FALSE, ...)
+parsers$`text/tab-separated-values` <- function(x, type = NULL, encoding = NULL, ...) {
+  text <- parse_text(x, type = type, encoding = encoding)
+  read.delim(text = text, stringsAsFactors = FALSE, ...)
 }
